@@ -29,8 +29,8 @@
 #endif  
 //LXDEPCHECK - standard libraries
 
-#include "lxGUI.h"
 #include "lxData.h"
+#include "lxGUI.h"
 #include "lxSetup.h"
 #include "lxRender.h"
 #include "lxOptDlg.h"
@@ -514,7 +514,7 @@ void lxFrame::ToggleFullScreen() {
 
 
 int lxFrame::GetFileType(wxString fName) {
-#define matchtype(w,t) if (fName.EndsWith((const wxChar *)wxString(_T(w)))) return t;
+#define matchtype(w,t) if (fName.EndsWith(wxString(_T(w)))) return t;
   matchtype(".lox",1);
   matchtype(".LOX",1);
   matchtype(".plt",2);
@@ -1163,7 +1163,7 @@ bool lxApp::OnInit()
 
 #if wxUSE_DISPLAY
     //multi screen support
-    wxDisplay display(0); //Get the settings for screen 0
+    wxDisplay display((unsigned int)0); //Get the settings for screen 0
     wxRect displayRect = display.GetGeometry();
 #else
     wxSize scr = wxGetDisplaySize();
@@ -1238,9 +1238,13 @@ void lxFrame::ExportRotationPictures() {
   this->canvas->setup->cam_orig_center = this->canvas->setup->cam_center;
   this->canvas->setup->cam_orig_pos = this->canvas->setup->cam_pos;
   for(i = 0; i < 600; i++) {
-    tmpRD->m_imgFileName = this->m_fileDir;
-	tmpRD->m_imgFileName += _T("/");
-	tmpRD->m_imgFileName += wxString::Format(_T("ROT%04d.png"), i);
+  	if (!this->m_fileDir.IsEmpty()) {
+			tmpRD->m_imgFileName = this->m_fileDir;
+			tmpRD->m_imgFileName += _T("/");
+  	} else {
+  		tmpRD->m_imgFileName = _T("");
+  	}
+    tmpRD->m_imgFileName += wxString::Format(_T("ROT%04d.png"), i);
     tmpRD->Render(this, this->canvas);
 	this->canvas->SwapBuffers();
 	if (i == 0) {
