@@ -12,13 +12,18 @@ def run(s):
 
 try:
   release = run('git tag --points-at HEAD') # check for a TAG in the current commit
-  date = run('git show -s --format="%cd" --date=short HEAD')
+  if subprocess.check_output('git status -s', shell=True): # check for uncommitted changes
+    uncommitted = '+dev'
+    date = datetime.date.today().isoformat()
+  else:
+    uncommitted = ''
+    date = run('git show -s --format="%cd" --date=short HEAD')
   if release.startswith('v'):   # release number if the commit is tagged
-    ver = "%s (%s)" % (release[1:], date) 
+    ver = "%s (%s)" % (release[1:]+uncommitted, date) 
   else:                         # otherwise last known tag + short commit hash
     prevver = run('git describe --abbrev=0 --tags HEAD')
     commit = run('git rev-parse --short HEAD')
-    ver = "%s+%s (%s)" % (prevver[1:], commit, date)
+    ver = "%s+%s (%s)" % (prevver[1:], commit+uncommitted, date)
 except:   # no git version available
   patt = r'Therion (\d+\.\d+(?:\.\d+)?) \((\d{4}-\d\d-\d\d)\):$'
   try:   # check the file CHANGES for version info on the first line (this would be a released version)
@@ -36,7 +41,7 @@ except:   # no git version available
         if m:
           ver1 = m.group(1)
           break
-    ver = "%s+? (compiled on %s)" % (ver1, datetime.date.today().isoformat())
+    ver = "%s+dev (compiled on %s)" % (ver1, datetime.date.today().isoformat())
 
 try:
     oldver = open('thversion.h').read()
