@@ -55,6 +55,7 @@ thdata::thdata()
   this->d_flags = TT_LEGFLAG_NONE;
   this->d_extend = TT_EXTENDFLAG_NORMAL;
   this->d_vtresh = 67.5;
+  this->d_extend_ratio = thnan;
   this->d_shape = TT_DATALEG_SHAPE_OCTAGON;
   this->d_walls = TT_AUTO;
   this->d_last_equate = 0;
@@ -559,12 +560,6 @@ void thdata::self_print_properties(FILE * outf)
 }
 
 
-void thdata::self_delete()
-{
-  delete this;
-}
-
-
 void thdata::set_data_calibration(int nargs, char ** args)
 {
   static int items[THDATA_MAX_ITEMS];
@@ -1643,7 +1638,8 @@ void thdata::insert_data_leg(int nargs, char ** args)
     this->cd_leg->data_type = this->d_type;
     this->cd_leg->s_mark = this->d_mark;
     this->cd_leg->flags = this->d_flags;
-    this->cd_leg->extend = (unsigned char) this->d_extend;
+    this->cd_leg->extend = (unsigned int) this->d_extend;
+    this->cd_leg->extend_ratio = this->d_extend_ratio;
     this->d_extend &= (TT_EXTENDFLAG_DIRECTION | TT_EXTENDFLAG_IGNORE | TT_EXTENDFLAG_HIDE);
 
     this->cd_leg->psurvey = this->db->get_current_survey();
@@ -1823,10 +1819,15 @@ void thdata::insert_data_leg(int nargs, char ** args)
           case TT_SV_NUMBER:
             val = this->dlc_gradient.evaluate(val);
             val = this->dlu_gradient.transform(val);
+            if ((val >= 269.99999) && (val <= 360.00001))
+            	val -= 360.0;
             if ((val <= -90.00001) || (val >= 90.00001))
               ththrow(("gradient reading out of range -- %s", args[carg]))
-            else
+            else {
+              if (val < -90.0) val = -90.0;
+              if (val >  90.0) val =  90.0;
               this->cd_leg->gradient = val;
+            }
             break;
 //          case TT_SV_NAN:
           case TT_SV_UP:
@@ -2228,7 +2229,8 @@ void thdata::set_data_fix(int nargs, char ** args)
   it->sdx = thnan;
   it->sdy = thnan;
   it->sdz = thnan;
-  this->convert_cs(args[1], args[2], it->x, it->y);
+  it->cs = this->cs;
+  this->read_cs(args[1], args[2], it->x, it->y);
   for(ai = 0; ai < nargs; ai++) {
     if (ai > 2) {
       thparse_double(vid, val, args[ai]);
@@ -2514,11 +2516,33 @@ void thdata::set_data_flags(int nargs, char ** args)
   
 void thdata::set_data_extend(int nargs, char ** args)
 {
-  int cextend;
+  int cextend, exn;
+  double tmpdbl;
+  unsigned from_index, to_index;
+  from_index = 1;
+  to_index = 2;
   thdataextend dumm;
   cextend = thmatch_token(args[0], thtt_extendflag);
-  if (cextend == TT_EXTENDFLAG_UNKNOWN)
-    ththrow(("unknown extend flag -- %s", args[0]))
+  bool ratio_ok;
+  ratio_ok = false;
+  if (cextend == TT_EXTENDFLAG_UNKNOWN) {
+	  if ((nargs >= 1) && (nargs <= 3)) {
+	    thparse_double(exn, tmpdbl, args[0]);
+		  if (exn == TT_SV_NUMBER) {
+			  if ((tmpdbl < 0.0) || (tmpdbl > 200.0))
+				  ththrow(("extend ratio out of range [0..200] -- %s", args[0]))
+				ratio_ok = true;
+        if (nargs == 1) {
+          this->d_extend_ratio = tmpdbl / 100.0;
+          return;
+        }
+        else
+          dumm.extend_ratio = tmpdbl / 100.0;
+		  }
+	  }
+	  if (!ratio_ok)
+	    ththrow(("unknown extend flag -- %s", args[0]))
+  }
   switch (nargs) {
     case 1:
       if ((cextend & TT_EXTENDFLAG_DIRECTION) != 0) {
@@ -2526,12 +2550,16 @@ void thdata::set_data_extend(int nargs, char ** args)
       }
       this->d_extend |= cextend;
       break;
+    case 4:
+	    thparse_objectname(dumm.before, & this->db->buff_stations, args[1], this);
+	    to_index = 3;
+	    from_index = 2;
     case 3:
       // parsnut mena to bodu
-	    thparse_objectname(dumm.to, & this->db->buff_stations, args[2], this);
+	    thparse_objectname(dumm.to, & this->db->buff_stations, args[to_index], this);
     case 2:
       // parsnut meno from bodu a prida
-	    thparse_objectname(dumm.from, & this->db->buff_stations, args[1], this);
+	    thparse_objectname(dumm.from, & this->db->buff_stations, args[from_index], this);
       dumm.extend = cextend;
       dumm.srcf = this->db->csrc;
       dumm.psurvey = this->db->get_current_survey();
@@ -2818,7 +2846,7 @@ void thdata::end_group() {
     this->cgroup->dims_list.insert(this->cgroup->dims_list.end(), (*di));
   }
   
-  tmp->self_delete();
+  delete tmp;
 }
 
 
@@ -2932,7 +2960,13 @@ void thdata::complete_dimensions()
 }
 
 
+void thdata::convert_all_cs() {
+  thdatafix_list::iterator it;
+  for(it = this->fix_list.begin(); it != this->fix_list.end(); it++) {
+	  this->convert_cs(it->cs, it->x, it->y, it->x, it->y);
+  }
 
+}
 
 
 
