@@ -61,17 +61,6 @@ class thdatastation : public thdataobject {
    */
   
   virtual bool is(int class_id);
-  
-  
-  /**
-   * Delete this object.
-   *
-   * @warn Always use this method instead of delete function.
-   */
-   
-  virtual void self_delete();
-
-
 };
 
 
