@@ -39,7 +39,6 @@
 #include <cstring>
 #include <cstdio>
 #include <cmath>
-#include <cassert>
 
 #include "thepsparse.h"
 #include "thpdfdbg.h"
@@ -277,6 +276,13 @@ void MP_data::add(int i, string s) {
     ss >> set.data[1];
     ss >> set.data[2];
   }
+  else if (i == MP_cmyk) {
+    istringstream ss(s);
+    ss >> set.data[0];
+    ss >> set.data[1];
+    ss >> set.data[2];
+    ss >> set.data[3];
+  }
   else if (i == MP_pattern) {
     set.pattern = s;
   }
@@ -331,6 +337,10 @@ void MP_setting::print_svg (ofstream & F, CGS & gstate) {
       for (int i=0; i<3; i++) gstate.color[i] = data[0];
       gstate.pattern = "";
       break;
+    case MP_cmyk:  // cmyk to rgb conversion necessary in SVG
+      for (int i=0; i<3; i++) gstate.color[i] = 1.0 - min(1.0, data[i] + data[3]);
+      gstate.pattern = "";
+      break;
     case MP_pattern:
       gstate.pattern = pattern;
       break;
@@ -410,7 +420,7 @@ void MP_data::print_svg (ofstream & F, string unique_prefix) {
   }
 //  F << "</g>" << endl;
   
-  assert(gstate.clippathdepth.empty());
+  thassert(gstate.clippathdepth.empty());
 }
 
 void converted_data::print_svg (ofstream & F, string unique_prefix) { 
@@ -482,7 +492,7 @@ string process_pdf_string2(string s, string font) {
   map<string,FONTCHARS>::iterator I; 
 
   I = USED_CHARS.find(font);
-  assert (I != USED_CHARS.end());
+  thassert (I != USED_CHARS.end());
   s = s.substr(1,s.length()-3);  // delete surrounding parentheses and final space
   for (unsigned i=0; i<s.size(); i++) {
     c = s[i];
@@ -718,6 +728,14 @@ void parse_eps(string fname, string cname, double dx, double dy,
 	}
         thbuffer.clear();
       }
+      else if (tok == "setcmykcolor") {
+        if (already_transp) {  // transp off
+          data.MP.add(MP_transp_off);
+          already_transp = false;
+        }
+        data.MP.add(MP_cmyk, thbuffer[0]+" "+thbuffer[1]+" "+thbuffer[2]+" "+thbuffer[3]);
+        thbuffer.clear();
+      }
       else if (tok == "setdash") {
         buffer = "";
         for(unsigned i=0; i<thbuffer.size(); i++) {
