@@ -46,6 +46,7 @@
 #include "thcs.h"
 #include "thtexfonts.h"
 #include "thlang.h"
+#include <libgen.h>
 
 
 thexpmodel::thexpmodel() {
@@ -236,6 +237,7 @@ void thexpmodel::export_3d_file(class thdatabase * dbp)
     thwarning(("can't open %s for output",fnm))
     return;
   }
+  this->register_output(fnm);
 
   unsigned long last_st = nstat, cur_st, cnlegs = 0;
   bool check_traverses = (dbp->db1d.traverse_list.size() > 0);
@@ -405,6 +407,7 @@ void thexpmodel::export_plt_file(class thdatabase * dbp)
     thwarning(("can't open %s for output",fnm))
     return;
   }
+  this->register_output(fnm);
 
   unsigned long last_st = nstat, cur_st;
   double xmin = 0.0, xmax = 0.0, ymin = 0.0, ymax = 0.0, 
@@ -686,6 +689,7 @@ void thexpmodel::export_vrml_file(class thdatabase * dbp) {
     thwarning(("can't open %s for output",fnm))
     return;
   }
+  this->register_output(fnm);
 
   thdb_object_list_type::iterator obi;
   thdb3ddata * pgn = dbp->db1d.get_3d(), 
@@ -939,6 +943,7 @@ void thexpmodel::export_3dmf_file(class thdatabase * dbp) {
     thwarning(("can't open %s for output",fnm))
     return;
   }
+  this->register_output(fnm);
 
   double avx, avy, avz;
   thdb_object_list_type::iterator obi;
@@ -1142,9 +1147,7 @@ void thexpmodel::export_dxf_file(class thdatabase * dbp) {
     thwarning(("can't open %s for output",fnm))
     return;
   }
-
-
-
+  this->register_output(fnm);
 
   double avx, avy, avz;
   thdb_object_list_type::iterator obi;
@@ -1788,7 +1791,10 @@ void thexpmodel::export_lox_file(class thdatabase * dbp) {
     for (size_t ii = 0; ii < nstat; ii++) {
       if (stnum_orig[ii] > 0) {
         pst = &(dbp->db1d.station_vec[ii]);
-        d3d = pst->get_3d_outline();
+        if (pst->survey->is_selected())
+        	d3d = pst->get_3d_outline();
+        else
+        	d3d = NULL;
         if ((d3d != NULL) && (d3d->nfaces > 0)) {
           expf_scrap.m_id = survnum;
           expf_scrap.m_surveyId = pst->survey->num1;
@@ -1858,6 +1864,7 @@ void thexpmodel::export_lox_file(class thdatabase * dbp) {
     thwarning(("error writing %s",fnm))
     return;
   }
+  this->register_output(fnm);
 
   
 #ifdef THDEBUG
@@ -1882,6 +1889,7 @@ void thexpmodel::export_kml_file(class thdatabase * dbp)
     thwarning(("can't open %s for output",fnm))
     return;
   }
+  this->register_output(fnm);
 
 #ifdef THDEBUG
   thprintf("\n\nwriting %s\n", fnm);
