@@ -159,11 +159,6 @@ void thimport::set(thcmd_option_desc cod, char ** args, int argenc, unsigned lon
 }
 
 
-void thimport::self_delete()
-{
-  delete this;
-}
-
 void thimport::self_print_properties(FILE * outf)
 {
   thdataobject::self_print_properties(outf);
@@ -176,7 +171,7 @@ void thimport::set_file_name(char * fnm)
   
   thbuffer impf_path;
   impf_path.guarantee(1024);
-  getcwd(impf_path.get_buffer(),1024);
+  thassert(getcwd(impf_path.get_buffer(),1024) != NULL);
   
   this->mysrc = this->db->csrc;
   
@@ -327,10 +322,14 @@ const char * thimport::station_name(const char * sn, const char separator, struc
               else
                 this->db->lcsobjectptr = this->db->csurveyptr->loptr;
               this->db->ccontext = THCTX_SURVEY;
-              nsurvey = (thsurvey*) this->db->create("survey", this->mysrc);
-              // TODO - nastavit mu meno cez set
-              nsurvey->name = this->db->strstore(cbf[active_survey]);
-              this->db->insert(nsurvey);
+
+              {
+                auto unique_nsurvey = this->db->create("survey", this->mysrc);
+                nsurvey = dynamic_cast<thsurvey*>(unique_nsurvey.get());
+                // TODO - nastavit mu meno cez set
+                nsurvey->name = this->db->strstore(cbf[active_survey]);
+                this->db->insert(std::move(unique_nsurvey));
+              }
               this->db->csrc.context = this;
               this->db->csurveylevel--;
 //              nendsurvey = (thendsurvey*) this->db->create("endsurvey", this->mysrc);
