@@ -74,6 +74,7 @@ thlayout::thlayout()
   this->ox = thnan;
   this->oy = thnan;
   this->oz = thnan;
+  this->o_cs = TTCS_LOCAL;
 
   this->def_size = 0;
   this->hsize = 0.18;
@@ -95,6 +96,8 @@ thlayout::thlayout()
   this->gox = thnan;
   this->goy = thnan;
   this->goz = thnan;
+  this->go_cs = TTCS_LOCAL;
+
   
   this->def_grid_size = 0;
   this->gxs = thnan;
@@ -204,6 +207,10 @@ thlayout::thlayout()
   this->explo_lens = TT_LAYOUT_LENSTAT_HIDE;
   this->def_topo_lens = 0;
   this->topo_lens = TT_LAYOUT_LENSTAT_HIDE;
+  this->def_carto_lens = 0;
+  this->carto_lens = TT_LAYOUT_LENSTAT_HIDE;
+  this->def_copy_lens = 0;
+  this->copy_lens = TT_LAYOUT_LENSTAT_HIDE;
 
   this->def_lang = 0;
   this->lang = thcfg.get_lang();
@@ -376,13 +383,17 @@ enum {
   TTL_MAPITEM_TOPO,
   TTL_MAPITEM_EXPLO_LENS,
   TTL_MAPITEM_TOPO_LENS,
+  TTL_MAPITEM_CARTO_LENS,
+  TTL_MAPITEM_COPY_LENS,
   TTL_MAPITEM_SORT,
   TTL_MAPITEM_UNKNOWN,
 };
 
 static const thstok thlayout__mapitems[] = {
   {"carto", TTL_MAPITEM_CARTO},
+  {"carto-count", TTL_MAPITEM_CARTO_LENS},
   {"copyright", TTL_MAPITEM_COPYRIGHT},
+  {"copyright-count", TTL_MAPITEM_COPY_LENS},
   {"explo", TTL_MAPITEM_EXPLO},
   {"explo-length", TTL_MAPITEM_EXPLO_LENS},
   {"topo", TTL_MAPITEM_TOPO},
@@ -527,6 +538,20 @@ void thlayout::set(thcmd_option_desc cod, char ** args, int argenc, unsigned lon
           this->topo_lens = sv;
           this->def_topo_lens = 2;
           break;
+        case TTL_MAPITEM_CARTO_LENS:
+          sv = thmatch_token(args[1],thtt_layout_lenstat);
+          if (sv == TT_LAYOUT_LENSTAT_UNKNOWN)
+            ththrow(("invalid map-item carto-length switch -- %s",args[1]))
+          this->carto_lens = sv;
+          this->def_carto_lens = 2;
+          break;
+        case TTL_MAPITEM_COPY_LENS:
+          sv = thmatch_token(args[1],thtt_layout_lenstat);
+          if (sv == TT_LAYOUT_LENSTAT_UNKNOWN)
+            ththrow(("invalid map-item copyright-length switch -- %s",args[1]))
+          this->copy_lens = sv;
+          this->def_copy_lens = 2;
+          break;
         case TTL_MAPITEM_EXPLO:
         case TTL_MAPITEM_TOPO:
         case TTL_MAPITEM_CARTO:
@@ -623,7 +648,8 @@ void thlayout::set(thcmd_option_desc cod, char ** args, int argenc, unsigned lon
 
     case TT_LAYOUT_ORIGIN:
       //this->parse_len(this->ox, this->oy, this->oz, 3, args, -1);
-      this->convert_cs(args[0], args[1], this->ox, this->oy);
+      this->o_cs = this->cs;
+      this->read_cs(args[0], args[1], this->ox, this->oy, false);
       if (this->cs == TTCS_LOCAL) {
         this->parse_len(this->ox, this->oy, this->oz, 3, args, -1);
       } else {
@@ -695,7 +721,8 @@ void thlayout::set(thcmd_option_desc cod, char ** args, int argenc, unsigned lon
     
 
     case TT_LAYOUT_GRID_ORIGIN:
-      this->convert_cs(args[0], args[1], this->gox, this->goy);
+      this->go_cs = this->cs;
+      this->read_cs(args[0], args[1], this->gox, this->goy, false);
       if (this->cs == TTCS_LOCAL) {
         this->parse_len(this->gox, this->goy, this->goz, 3, args, -1);
       } else {
@@ -1048,11 +1075,6 @@ void thlayout::set(thcmd_option_desc cod, char ** args, int argenc, unsigned lon
 }
 
 
-void thlayout::self_delete()
-{
-  delete this;
-}
-
 void thlayout::self_print_properties(FILE * outf)
 {
   thdataobject::self_print_properties(outf);
@@ -1174,6 +1196,10 @@ void thlayout::self_print_library() {
   thprintf("\tplayout->explo_lens = %d;\n",this->explo_lens);
   thprintf("\tplayout->def_topo_lens = %d;\n",this->def_topo_lens);
   thprintf("\tplayout->topo_lens = %d;\n",this->topo_lens);
+  thprintf("\tplayout->def_carto_lens = %d;\n",this->def_carto_lens);
+  thprintf("\tplayout->carto_lens = %d;\n",this->carto_lens);
+  thprintf("\tplayout->def_copy_lens = %d;\n",this->def_copy_lens);
+  thprintf("\tplayout->copy_lens = %d;\n",this->copy_lens);
 
   thprintf("\tplayout->def_lang = %d;\n", this->def_lang);
   thprintf("\tplayout->lang = %s;\n",thlang_getcxxid(this->lang));
@@ -1562,7 +1588,7 @@ void thlayout::export_pdftex(FILE * o, thdb2dprj * prj, char mode) {
   char * pp;
   long i;
   pict_path.guarantee(1024);
-  getcwd(pict_path.get_buffer(),1024);
+  thassert(getcwd(pict_path.get_buffer(),1024) != NULL);
   pp = pict_path.get_buffer();
   pl = strlen(pp);
   if ((pl > 0) && ((pp[pl-1] == '/') || (pp[pl-1] == '\\'))) {
@@ -1717,7 +1743,8 @@ void thlayout::process_copy() {
         this->base_scale = srcl->base_scale;
       endcopy
 
-      begcopy(def_origin) 
+      begcopy(def_origin)
+        this->o_cs = srcl->o_cs;
         this->ox = srcl->ox;
         this->oy = srcl->oy;
         this->oz = srcl->oz;
@@ -1746,6 +1773,7 @@ void thlayout::process_copy() {
       endcopy
   
       begcopy(def_grid_origin)
+        this->go_cs = srcl->go_cs;
         this->gox = srcl->gox;
         this->goy = srcl->goy;
         this->goz = srcl->goz;
@@ -1939,6 +1967,14 @@ void thlayout::process_copy() {
         this->topo_lens = srcl->topo_lens;
       endcopy
 
+	  begcopy(def_carto_lens)
+        this->carto_lens = srcl->carto_lens;
+      endcopy
+
+      begcopy(def_copy_lens)
+        this->copy_lens = srcl->copy_lens;
+      endcopy
+
       begcopy(def_lang)
         this->lang = srcl->lang;
       endcopy
@@ -2203,5 +2239,11 @@ void thlayout::export_mptex_font_size(FILE * o, th2ddataobject * obj, bool print
 
 }
 
+void thlayout::convert_all_cs() {
+	if (!thisnan(this->ox))
+		this->convert_cs(this->o_cs, this->ox, this->oy, this->ox, this->oy);
+	if (!thisnan(this->gox))
+		this->convert_cs(this->go_cs, this->gox, this->goy, this->gox, this->goy);
+}
 
 
