@@ -520,11 +520,13 @@ class thlayout : public thdataobject {
 
   class thconfig * m_pconfig;
 
-  class thlookup * m_lookup;
+  std::unique_ptr<thlookup> m_lookup;
     
   double scale, scale_bar, base_scale, ox, oy, oz, hsize, vsize, paphs, papvs, paghs, pagvs, marls, marts, gxs, gys, gzs, gox, goy, goz, navf, overlap, opacity,
     map_header_x, map_header_y, legend_width, surface_opacity, rotate;
   
+  int o_cs, go_cs;
+
   const char * olx, * oly, 
     * doc_title, * doc_comment, * doc_author, * doc_subject, * doc_keywords, * excl_list;
   
@@ -547,7 +549,7 @@ class thlayout : public thdataobject {
   bool titlep, transparency, layers, pgsnum, lock, excl_pages, page_grid, 
     map_header_bg, sketches, color_labels;
 
-  int explo_lens, topo_lens;
+  int explo_lens, topo_lens, carto_lens, copy_lens;
 		
 	thlocale units;
 
@@ -565,7 +567,7 @@ class thlayout : public thdataobject {
     def_max_explos, def_max_topos, def_max_cartos,
     def_max_copys, def_explo_lens, def_topo_lens, def_debug, def_survey_level, def_surface,
     def_surface_opacity, def_units, def_grid_coords, def_color_labels,
-    def_font_setup, def_min_symbol_scale;
+    def_font_setup, def_min_symbol_scale, def_carto_lens, def_copy_lens;
     
   
   thlayout_copy_src * first_copy_src, * last_copy_src;
@@ -644,15 +646,6 @@ class thlayout : public thdataobject {
   virtual void set(thcmd_option_desc cod, char ** args, int argenc, unsigned long indataline);
 
 
-  /**
-   * Delete this object.
-   *
-   * @warn Always use this method instead of delete function.
-   */
-   
-  virtual void self_delete();
-
-
   /**
    * Print object properties.
    */
@@ -719,6 +712,12 @@ class thlayout : public thdataobject {
    */
    
   void set_thpdf_layout(thdb2dprj * prj, double x_scale, double x_origin_shx, double x_origin_shy);
+
+  /**
+   * Convert all points in object.
+   */
+
+  virtual void convert_all_cs();
    
 
 };
