@@ -166,15 +166,6 @@ class thlookup : public thdataobject {
   virtual void set(thcmd_option_desc cod, char ** args, int argenc, unsigned long indataline);
 
 
-  /**
-   * Delete this object.
-   *
-   * @warn Always use this method instead of delete function.
-   */
-   
-  virtual void self_delete();
-
-
   /**
    * Get context for object.
    */
@@ -221,7 +212,7 @@ class thlookup : public thdataobject {
    * Export color legend, if applicable.
    */
 
-  virtual void export_color_legend(thlayout * layout);
+  virtual void export_color_legend(thlayout * layout, std::unique_ptr<thlookup> lookup_holder);
 
 };
 
