@@ -819,10 +819,10 @@ void thdecode_utf2tex(thbuffer * dest, const char * src)
 void thdecode_sql(thbuffer * dest, const char * src)
 {
 
-  size_t srcln = strlen(src), srcx = 0;
+  size_t srcln, srcx = 0;
   unsigned char * srcp, * dstp;
 //  unsigned num;
-  if ((src == NULL) || (srcln == 0)) {
+  if ((src == NULL) || ((srcln = strlen(src)) == 0)) {
     *dest = "NULL";
     return;
   }
@@ -1005,7 +1005,7 @@ void thparse_image(const char * fname, double & width, double & height, double &
       int marker;
       size_t len;
       pictf = fopen(fname, "rb");      
-      fread(&(picth[0]), 1, 2, pictf);
+      thassert(fread(&(picth[0]), 1, 2, pictf) == 2);
       height = -1.0;
       width = -1.0;
       while(getc(pictf) == 255) {
