@@ -82,6 +82,7 @@ thscrap::thscrap()
   this->scale_p2y = 0.0;
   this->scale_p9 = false;
   this->reset_limits();
+  this->scale_cs = TTCS_LOCAL;
 
   this->reset_transformation();
 
@@ -225,12 +226,6 @@ void thscrap::set(thcmd_option_desc cod, char ** args, int argenc, unsigned long
   }
 }
 
-void thscrap::self_delete()
-{
-  delete this;
-}
-
-
 void thscrap::self_print_properties(FILE * outf)
 {
   thdataobject::self_print_properties(outf);
@@ -299,8 +294,9 @@ void thscrap::parse_scale(char * ss)
         this->scale_r2y = lentf.transform(this->scale_r2y);
       }
     } else {
-      this->convert_cs(pars[4], pars[5], this->scale_r1x, this->scale_r1y);
-      this->convert_cs(pars[6], pars[7], this->scale_r2x, this->scale_r2y);
+      this->scale_cs = this->cs;
+      this->read_cs(pars[4], pars[5], this->scale_r1x, this->scale_r1y);
+      this->read_cs(pars[6], pars[7], this->scale_r2x, this->scale_r2y);
     }
     if (hypot(this->scale_r1x - this->scale_r2x,
       this->scale_r1y - this->scale_r2y) == 0.0)
@@ -1087,6 +1083,9 @@ void thscrap::process_3d() {
     
   this->d3_parsed = true;
 
+  if (this->d3 == TT_FALSE)
+	  return;
+
   thprintf(".");
 
   thscrapis is(this);
@@ -1485,7 +1484,7 @@ void thscrap::parse_sketch(char ** args, int argenc)
   thparse_double(sv,sk.m_y,args[2]);
   if ((sv	!= TT_SV_NUMBER) &&	(sv	!= TT_SV_NAN))
     ththrow(("invalid	number --	%s", args[2]))
-  this->sketch_list.push_back(sk);
+  this->sketch_list.push_back(std::move(sk));
 }
 
 
@@ -1499,8 +1498,12 @@ void thscrap::start_insert() {
 }
 
 
-
-
+void thscrap::convert_all_cs() {
+    if (this->scale_cs != TTCS_LOCAL) {
+        this->convert_cs(this->scale_cs, this->scale_r1x, this->scale_r1y, this->scale_r1x, this->scale_r1y);
+        this->convert_cs(this->scale_cs, this->scale_r2x, this->scale_r2y, this->scale_r2x, this->scale_r2y);
+	}
+}
 
 
 
