@@ -225,6 +225,18 @@ void thsvxctrl::write_survey_leg(thdataleg * legp)
         break;
     }
   }
+  
+  if (legp->flags != this->pdl.flags) {
+    fprintf(this->svxf,"*flags");
+    if ((legp->flags & TT_LEGFLAG_DUPLICATE) == TT_LEGFLAG_NONE) fprintf(this->svxf," not");
+    fprintf(this->svxf," duplicate");
+    if ((legp->flags & TT_LEGFLAG_SURFACE) == TT_LEGFLAG_NONE) fprintf(this->svxf," not");
+    fprintf(this->svxf," surface");
+    if ((legp->flags & TT_LEGFLAG_SPLAY) == TT_LEGFLAG_NONE) fprintf(this->svxf," not");
+    fprintf(this->svxf," splay");
+    fprintf(this->svxf,"\n");
+    this->svxf_ln++;
+  }
 
   // now print the data
   // first stations
@@ -329,14 +341,14 @@ void thsvxctrl::process_survey_data(class thdatabase * dbp)
   //thdatass_list::iterator ssi;
   thdataequate_list::iterator eqi;
   thdata * dp;
-  thdataobject * cx1, * cx2;
-  thdb1ds * tmps;
+  //thdataobject * cx1, * cx2;
+  //thdb1ds * tmps;
   
   while (obi != dbp->object_list.end()) {
   
     if ((*obi)->get_class_id() == TT_DATA_CMD) {
       
-      dp = (thdata *)(*obi);
+      dp = (thdata *)(*obi).get();
       
       // scan data shots
       lei = dp->leg_list.begin();
@@ -349,12 +361,12 @@ void thsvxctrl::process_survey_data(class thdatabase * dbp)
       // scan data fixes
       fii = dp->fix_list.begin();
       while(fii != dp->fix_list.end()) {
-        tmps = &(dbp->db1d.station_vec[fii->station.id - 1]);
-        cx1 = tmps->fixcontext;
-        cx2 = fii->srcf.context;
-        if (((cx1 == NULL) && (cx2 == NULL)) || ((cx1 != NULL) && (cx2 != NULL) && (cx1->id == cx2->id))) {
+        //tmps = &(dbp->db1d.station_vec[fii->station.id - 1]);
+        //cx1 = tmps->fixcontext;
+        //cx2 = fii->srcf.context;
+        //if (((cx1 == NULL) && (cx2 == NULL)) || ((cx1 != NULL) && (cx2 != NULL) && (cx1->id == cx2->id))) {
           this->write_survey_fix(&(*fii));
-        }
+        //}
         fii++;
       }
   
@@ -386,7 +398,7 @@ void thsvxctrl::process_survey_data(class thdatabase * dbp)
   // run survex
   thbuffer svxcom, wdir;
   wdir.guarantee(1024);
-  getcwd(wdir.get_buffer(),1024);
+  thassert(getcwd(wdir.get_buffer(),1024) != NULL);
   int retcode;
   svxcom = "\"";
   svxcom += thini.get_path_cavern();
@@ -590,6 +602,7 @@ void thsvxctrl::transcript_log_file(class thdatabase * dbp, const char * lfnm)
     char * start_ch = NULL; //, * test_ch;
     int num_type;
     thsvxctrl_src_maptype::iterator srcmi;
+    const auto prev_char_is = [&lnbuff, &start_ch](const char c) { return (start_ch - 1) >= lnbuff && start_ch[-1] == c; };
 //    if (*lnbuff == 13) lnbuff++;
 //    if (strncmp(lnbuff,"There were",10) == 0)
 //      chidx = 2049;
@@ -625,7 +638,7 @@ void thsvxctrl::transcript_log_file(class thdatabase * dbp, const char * lfnm)
         else {
           num_type = THSVXLOGNUM_STATION;
           if ((chidx > 0) && (chidx <= nchs)) {
-            if ((start_ch[-1] == ':') && (*chch == ':'))
+            if (prev_char_is(':') && (*chch == ':'))
               num_type = THSVXLOGNUM_LINE;
           }
           if (num_type == THSVXLOGNUM_STATION) {
@@ -633,7 +646,7 @@ void thsvxctrl::transcript_log_file(class thdatabase * dbp, const char * lfnm)
               if ((*chch == '.') || (*chch == ',') || (*chch == ')') || (*chch == 'm')
                 || (*chch == '-') || (*chch == '/'))
                 num_type = THSVXLOGNUM_NONE;
-              if ((start_ch[-1] == '.') || (start_ch[-1] == '-'))
+              if (prev_char_is('.') || prev_char_is('-'))
                 num_type = THSVXLOGNUM_NONE;
             }
           }
@@ -719,7 +732,9 @@ void thsvxctrl::load_err_file(class thdatabase * dbp, const char * lfnm) {
 			i = 0;
 			while (i < b.get_size()) {
 //				thprintf("%s\n", b.get_buffer()[i]);
-				if (sscanf(b.get_buffer()[i], "%lu", &st)) {
+			  st = 0;
+			  sscanf(b.get_buffer()[i], "%lu", &st);
+				if (st > 0) {
 					nst++;
 					if (nst == 1) {
 						sf = st;
