@@ -36,10 +36,9 @@
 
 #include <cstring>
 #include <cstdio>
-#include <cassert>
 
 #include "thtexfonts.h"
-#include "thtexenc.cxx"
+#include "thtexenc.h"
 #include "thpdfdbg.h"
 #include "thinit.h"
 #include "thpdfdata.h"
@@ -91,13 +90,13 @@ int encodings_new::get_enc_pos (int ch) {
   }
 //cout << "==FP== " << m_fon[style][ch] << endl;
   return m_fon[ch];
-};
+}
 
 void encodings_new::write_enc_files() {
   if (NFSS==0) return;
 
   thprintf("generating TeX metrics ... ");
-  char fc[10];
+  char fc[12];
   string style[5] = {"rm", "it", "bf", "ss", "si"};
   string s;
 
@@ -140,7 +139,7 @@ void encodings_new::write_enc_files() {
         " -fkern --no-default-ligkern --no-virtual --name " + fname_tfm +
 //        " -fkern --no-default-ligkern --name " + fname_tfm +
 //        type1 + " --warn-missing "+otf_file[i]+" > thotftfm.tmp").c_str()) > 0)
-        type1 + otf_file[i]+" > thotftfm.tmp").c_str()) > 0)
+        type1 + otf_file[i]+" > thotftfm.tmp").c_str()) != 0)
           therror((("can't generate TFM file from "+otf_file[i]+" (LCDF typetools not installed?)").c_str()));
       ifstream G ("thotftfm.tmp");
       if (!G) therror(("could not read font mapping data\n"));
@@ -148,6 +147,7 @@ void encodings_new::write_enc_files() {
         getline(G,s);
         if (s.find("<") != string::npos) break;
       }
+      if (s.size() < 10) therror(("no usable otftotfm output"));
       if (s.substr(s.size()-3,3)=="otf" || s.substr(s.size()-3,3)=="OTF") {
         s.replace(s.rfind("<"), 1, "<<");  // OTF fonts must be fully embedded
       }
@@ -574,7 +574,7 @@ int tex2uni(string font, int ch) {
         id = J->id;
         break;
       }
-    //assert(id != -1);
+    //thassert(id != -1);
     ch %= 256;
     if (ch < 0) ch += 256;  // if string is based on signed char
     if (id == -1) {
@@ -588,7 +588,7 @@ int tex2uni(string font, int ch) {
   } else {  // NFSS
     string f_ind = font.substr(4,2);
     // basic check that we have a number
-    assert(f_ind[0] >= '0' && f_ind[0] <= '9' && f_ind[1] >= '0' && f_ind[1] <= '9');
+    thassert(f_ind[0] >= '0' && f_ind[0] <= '9' && f_ind[1] >= '0' && f_ind[1] <= '9');
     if (ch < 0) ch += 256;  // if string is based on signed char
     return ENC_NEW.get_uni(atoi(f_ind.c_str()),ch);
   }
